# Yet Another Network Analysis Toolkit.
At the moment, this bad boy containts a few network communication metrics and models at its `core` but the plan is to expand it to include more useful functions.
